agentUtils

package
v1.1.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	MinChromeVersion  = 125
	MinFirefoxVersion = 131
)

Functions

This section is empty.

Types

type UserAgentDetail

type UserAgentDetail struct {
	UserAgent string
	SecChUa   string
	Platform  string
	Browser   string
	Device    string
	OS        string
	Engine    string
	// contains filtered or unexported fields
}

UserAgentDetail is a struct that holds the details of a user agent It has a mutex to lock and unlock the struct.

func GetAndroidUserAgents

func GetAndroidUserAgents(count int) []*UserAgentDetail

GetAndroidUserAgents dynamically generates a list of UserAgentDetail based on the count provided

func GetDefaultUserAgents

func GetDefaultUserAgents() []*UserAgentDetail

GetDefaultUserAgents returns a list of default user agents that can be used for making requests

func (*UserAgentDetail) Lock

func (a *UserAgentDetail) Lock()

func (*UserAgentDetail) Unlock

func (a *UserAgentDetail) Unlock()

Jump to